
/*
 * me26.h -- definitions for the me26 module
 *
 *********/

#include "me26_ioctl.h"

/* version dependencies have been confined to a separate file */

#define VERSION_CODE(vers,rel,seq) ( ((vers)<<16) | ((rel)<<8) | (seq) )
#include "sysdep.h"


/*
 * Macros to help debugging
 */

#undef PDEBUG             /* undef it, just in case */
#ifdef ME26_DEBUG
#  ifdef __KERNEL__
     /* This one if debugging is on, and kernel space */
#    define PDEBUG(fmt, args...) printk( KERN_DEBUG "me26: " fmt, ## args)
#  else
     /* This one for user space */
#    define PDEBUG(fmt, args...) fprintf(stderr, fmt, ## args)
#  endif
#else
#  define PDEBUG(fmt, args...) /* not debugging: nothing */
#endif

#undef PDEBUGG
#define PDEBUGG(fmt, args...) /* nothing: it's a placeholder */

#ifndef ME26_NR_CARDS
#define ME26_NR_CARDS 4
#endif

#ifndef ME26_BASE1
#define ME26_BASE1 0x0700
#endif

#ifndef ME26_BASE2
#define ME26_BASE2 0x0780
#endif

#ifndef ME26_BASE3
#define ME26_BASE3 0x0F00
#endif

#ifndef ME26_BASE4
#define ME26_BASE4 0x0F80
#endif

#ifndef ME26_MAJOR
#define ME26_MAJOR 0   /* dynamic major by default */
#endif


/* *************************************************** */
/* PORTS */
#define AD_LSB 0x00
#define AD_MSB 0x01
#define AD_CONTROL 0x02
#define CARD_CONTROL 0x03
#define COUNTER_0     0x04
#define COUNTER_1     0x05
#define COUNTER_2     0x06
#define TIMER_CONTROL 0x07

/* *************************************************** */
/* Options for base + 0x07 = TIMER_CONTROL */
#define SET_COUNTER_0 0x34
#define SET_COUNTER_1 0x74

/* *************************************************** */
/* Options for base + 0x02 = AD_CONTROL */

/* Channel selection */
#define CHANNEL00             0x00
#define CHANNEL01             0x10
#define CHANNEL02             0x20
#define CHANNEL03             0x30
#define CHANNEL04             0x40
#define CHANNEL05             0x50
#define CHANNEL06             0x60
#define CHANNEL07             0x70
#define CHANNEL08             0x80
#define CHANNEL09             0x90
#define CHANNEL10             0xA0
#define CHANNEL11             0xB0
#define CHANNEL12             0xC0
#define CHANNEL13             0xD0
#define CHANNEL14             0xE0
#define CHANNEL15             0xF0

/* Interrupt enabling after A/D conversion */
#define ENABLE_INTERRUPT      0x08

/* No compatibility with cards older than Rev. 2.0 */
#define NO_OLD_COMPATIBILITY  0x04

/* A/D start with software or internal timer */
#define SOFT_TRIGGER          0x02

/* Start software trigerring of A/D */
#define GO                    0x01 


/*
 * Split minors in two parts
 */
#define CARD(dev)   (MINOR(dev) >> 5)  /* high nibble - 1 bit*/
#define CHANNEL(dev)    (MINOR(dev) & 0x1f) /* low  nibble + 1 bit*/


extern struct file_operations me26_fops;        /* simplest: global */

/*
 * The different configurable parameters
 */
extern int me26_major;     /* main.c */
extern int me26_nr_cards;

/*
 * Prototypes for shared functions
 */


read_write_t me26_read (struct inode *inode, struct file *filp,
                char *buf, count_t count);
int me26_ioctl (struct inode *inode, struct file *filp,
                 unsigned int cmd, unsigned long arg);


#ifdef ME26_DEBUG
#  if LINUX_VERSION_CODE > VERSION_CODE(1,99,3) /* 1.99.4 exported the needed symbols */
#    define ME26_USE_PROC
#  endif
#endif

#ifndef min
#  define min(a,b) ((a)<(b) ? (a) : (b))
#endif



typedef struct Me26_Dev {
  int trigger;
  int interrupt;
  unsigned char req_int;
  unsigned char single[16];
  unsigned long buffer[16];
  unsigned char timsin;
  unsigned long timbuf;
  volatile unsigned long timhead;
  volatile unsigned long timtail;
  volatile unsigned long head[16];
  volatile unsigned long tail[16];
} Me26_Dev;

